@@ -110,11 +110,17 @@ class Main(object):
         gtk.accel_map_add_entry('<tryton>/Form/Close', gtk.keysyms.W,
                 gtk.gdk.CONTROL_MASK)
         gtk.accel_map_add_entry('<tryton>/Form/Previous Tab',
-            gtk.keysyms.Page_Up, gtk.gdk.CONTROL_MASK)
+            gtk.keysyms.Left, gtk.gdk.CONTROL_MASK)
         gtk.accel_map_add_entry('<tryton>/Form/Next Tab',
-            gtk.keysyms.Page_Down, gtk.gdk.CONTROL_MASK)
+            gtk.keysyms.Right, gtk.gdk.CONTROL_MASK)
         gtk.accel_map_add_entry('<tryton>/Form/Reload', gtk.keysyms.R,
                 gtk.gdk.CONTROL_MASK)
+        gtk.accel_map_add_entry('<tryton>/Form/Attachments', gtk.keysyms.T,
+            gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK)
+        gtk.accel_map_add_entry('<tryton>/Form/Notes', gtk.keysyms.O,
+            gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK)
+        gtk.accel_map_add_entry('<tryton>/Form/Relate', gtk.keysyms.R,
+            gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK)
         gtk.accel_map_add_entry('<tryton>/Form/Actions', gtk.keysyms.E,
                 gtk.gdk.CONTROL_MASK)
         gtk.accel_map_add_entry('<tryton>/Form/Report', gtk.keysyms.P,
@@ -377,10 +383,28 @@ class Main(object):
         self.global_search_entry.grab_focus()
 
     def set_title(self, value=''):
-        title = CONFIG['client.title']
+        if CONFIG['login.profile']:
+            login_info = CONFIG['login.profile']
+        else:
+            login_info = '%s@%s/%s' % (
+                CONFIG['login.login'],
+                CONFIG['login.host'],
+                CONFIG['login.db'])
+        titles = [CONFIG['client.title'], login_info]
         if value:
-            title += ' - ' + value
-        self.window.set_title(title)
+            titles.append(value)
+        self.window.set_title(' - '.join(titles))
+        try:
+            style_context = self.window.get_style_context()
+        except AttributeError:
+            pass
+        else:
+            for name in style_context.list_classes():
+                if name.startswith('profile-'):
+                    style_context.remove_class(name)
+            if CONFIG['login.profile']:
+                style_context.add_class(
+                    'profile-%s' % CONFIG['login.profile'])
 
     def _set_menu_connection(self):
         menu_connection = gtk.Menu()
@@ -847,17 +871,17 @@ class Main(object):
             raise
         func = lambda parameters: rpc.login(
             host, port, database, username, parameters, language)
+        self.set_title()  # Adds username/profile while password is asked
         try:
             common.Login(func)
-        except Exception, exception:
-            if (isinstance(exception, TrytonError)
-                    and exception.faultCode == 'QueryCanceled'):
+        except TrytonError, exception:
+            if exception.faultCode == 'QueryCanceled':
                 return
-            if (isinstance(exception, TrytonServerError)
-                    and exception.faultCode.startswith('404')):
+            raise
+        except TrytonServerError, exception:
+            if exception.faultCode.startswith('404'):
                 return self.sig_login()
-            common.process_exception(exception)
-            return
+            raise
         self.get_preferences()
         self.favorite_unset()
         self.menuitem_favorite.set_sensitive(True)
@@ -967,7 +991,7 @@ class Main(object):
         self.menu_screen = None
         self.menu_expander_clear()
         action = PYSONDecoder().decode(prefs['pyson_menu'])
-        view_ids = False
+        view_ids = []
         if action.get('views', []):
             view_ids = [x[0] for x in action['views']]
         elif action.get('view_id', False):
@@ -1016,6 +1040,8 @@ class Main(object):
             lambda *a: gobject.idle_add(toggle_favorite, *a), treeview)
         # Unset fixed height mode to add column
         treeview.set_fixed_height_mode(False)
+        treeview.set_property(
+            'enable-grid-lines', gtk.TREE_VIEW_GRID_LINES_NONE)
         treeview.append_column(column)
 
         screen.search_filter()
@@ -1215,8 +1241,8 @@ class Main(object):
         if not urlp.scheme == 'tryton':
             return
         urlp = urlparse('http' + url[6:])
-        hostname, port = map(urllib.unquote,
-            (urlp.netloc.split(':', 1) + [CONFIG.defaults['login.port']])[:2])
+        hostname = common.get_hostname(urlp.netloc)
+        port = common.get_port(urlp.netloc)
         database, path = map(urllib.unquote,
             (urlp.path[1:].split('/', 1) + [''])[:2])
         if (not path or
@@ -1240,7 +1266,7 @@ class Main(object):
             res_id = None
             mode = None
             try:
-                view_ids = json.loads(params.get('views', 'false'))
+                view_ids = json.loads(params.get('views', '[]'))
                 limit = json.loads(params.get('limit', 'null'))
                 name = json.loads(params.get('name', '""'))
                 search_value = json.loads(params.get('search_value', '[]'),
@@ -1249,6 +1275,7 @@ class Main(object):
                     object_hook=object_hook)
                 context = json.loads(params.get('context', '{}'),
                     object_hook=object_hook)
+                context_model = params.get('context_model')
             except ValueError:
                 return
             if path:
@@ -1263,6 +1290,7 @@ class Main(object):
                     res_id=res_id,
                     domain=domain,
                     context=context,
+                    context_model=context_model,
                     mode=mode,
                     name=name,
                     limit=limit,
