@@ -21,7 +21,6 @@ from tryton.gui.window.view_form.view.screen_container import ScreenContainer
 from tryton.gui.window.view_form.view import View
 from tryton.signal_event import SignalEvent
 from tryton.config import CONFIG
-from tryton.exceptions import TrytonServerError, TrytonServerUnavailable
 from tryton.jsonrpc import JSONEncoder
 from tryton.common.domain_parser import DomainParser
 from tryton.common import RPCExecute, RPCException, MODELACCESS, \
@@ -31,6 +30,7 @@ from tryton.pyson import PYSONDecoder
 import tryton.rpc as rpc
 
 _ = gettext.gettext
+logger = logging.getLogger(__name__)
 
 
 class Screen(SignalEvent):
@@ -240,7 +240,7 @@ class Screen(SignalEvent):
         return list(self.domain_parser.completion(search_string))
 
     def search_filter(self, search_string=None, only_ids=False):
-        if self.context_screen:
+        if self.context_screen and not only_ids:
             context_record = self.context_screen.current_record
             if not context_record.validate():
                 self.clear()
@@ -390,6 +390,7 @@ class Screen(SignalEvent):
     def _group_changed(self, group, record):
         if not self.parent:
             self.display()
+        self.signal('group-changed', record)
 
     def __get_current_record(self):
         if (self.__current_record is not None
@@ -598,11 +599,13 @@ class Screen(SignalEvent):
         fields = self.current_view.get_fields()
         path = self.current_record.get_path(self.group)
         if self.current_view.view_type == 'tree':
-            saved = all(self.group.save())
+            # False value must be not saved
+            saved = all((x is 0 or x > 0 for x in self.group.save()))
             record_id = self.current_record.id if self.current_record else None
         elif self.current_record.validate(fields):
             record_id = self.current_record.save(force_reload=True)
-            saved = bool(record_id)
+            # False value must be not saved
+            saved = record_id is 0 or record_id > 0
         else:
             self.set_cursor()
             self.current_view.display()
@@ -735,6 +738,8 @@ class Screen(SignalEvent):
             return
         if (view.view_type == 'tree'
                 and not view.attributes.get('tree_state', False)):
+            # Mark as done to not set later when the view_type change
+            self.tree_states_done.add(id(view))
             return
         parent = self.parent.id if self.parent else None
         if parent is not None and parent < 0:
@@ -757,8 +762,9 @@ class Screen(SignalEvent):
                 expanded_nodes = json.loads(expanded_nodes)
                 selected_nodes = json.loads(selected_nodes)
             except RPCException:
-                logging.getLogger(__name__).warn(
-                    _('Unable to get view tree state'))
+                logger.warn(
+                    _('Unable to get view tree state for %s')
+                    % self.model_name)
             self.tree_states[parent][view.children_field] = (
                 timestamp, expanded_nodes, selected_nodes)
         if view.view_type == 'tree':
@@ -816,9 +822,9 @@ class Screen(SignalEvent):
                             self.model_name, json_domain, view.children_field,
                             json_paths, json_selected_path,
                             process_exception=False)
-                    except (TrytonServerError, TrytonServerUnavailable):
-                        logging.getLogger(__name__).warn(
-                            _('Unable to set view tree state'))
+                    except Exception:
+                        logger.warn(
+                            _('Unable to set view tree state'), exc_info=True)
 
     def get_tree_domain(self, parent):
         if parent:
@@ -911,25 +917,29 @@ class Screen(SignalEvent):
             self.current_record = record
         elif view.view_type == 'calendar':
             record = self.current_record
-            goocalendar = view.widgets['goocalendar']
-            date = goocalendar.selected_date
-            year = date.year
-            month = date.month
-            start = datetime.datetime(year, month, 1)
-            nb_days = calendar.monthrange(year, month)[1]
-            delta = datetime.timedelta(days=nb_days)
-            end = start + delta
-            events = goocalendar.event_store.get_events(start, end)
-            events.sort()
-            if not record:
-                self.current_record = len(events) and events[0].record
-            else:
-                for idx, event in enumerate(events):
-                    if event.record == record:
-                        next_id = idx + 1
-                        if next_id < len(events):
-                            self.current_record = events[next_id].record
-                        break
+            goocalendar = view.widgets.get('goocalendar')
+            if goocalendar:
+                date = goocalendar.selected_date
+                year = date.year
+                month = date.month
+                start = datetime.datetime(year, month, 1)
+                nb_days = calendar.monthrange(year, month)[1]
+                delta = datetime.timedelta(days=nb_days)
+                end = start + delta
+                events = goocalendar.event_store.get_events(start, end)
+                events.sort()
+                if not record:
+                    if events:
+                        self.current_record = events[0].record
+                    else:
+                        self.current_record = None
+                else:
+                    for idx, event in enumerate(events):
+                        if event.record == record:
+                            next_id = idx + 1
+                            if next_id < len(events):
+                                self.current_record = events[next_id].record
+                            break
         else:
             self.current_record = self.group[0] if len(self.group) else None
         self.set_cursor(reset_view=False)
@@ -968,25 +978,29 @@ class Screen(SignalEvent):
             self.current_record = record
         elif view.view_type == 'calendar':
             record = self.current_record
-            goocalendar = view.widgets['goocalendar']
-            date = goocalendar.selected_date
-            year = date.year
-            month = date.month
-            start = datetime.datetime(year, month, 1)
-            nb_days = calendar.monthrange(year, month)[1]
-            delta = datetime.timedelta(days=nb_days)
-            end = start + delta
-            events = goocalendar.event_store.get_events(start, end)
-            events.sort()
-            if not record:
-                self.current_record = len(events) and events[0].record
-            else:
-                for idx, event in enumerate(events):
-                    if event.record == record:
-                        prev_id = idx - 1
-                        if prev_id >= 0:
-                            self.current_record = events[prev_id].record
-                        break
+            goocalendar = view.widgets.get('goocalendar')
+            if goocalendar:
+                date = goocalendar.selected_date
+                year = date.year
+                month = date.month
+                start = datetime.datetime(year, month, 1)
+                nb_days = calendar.monthrange(year, month)[1]
+                delta = datetime.timedelta(days=nb_days)
+                end = start + delta
+                events = goocalendar.event_store.get_events(start, end)
+                events.sort()
+                if not record:
+                    if events:
+                        self.current_record = events[0].record
+                    else:
+                        self.current_record = None
+                else:
+                    for idx, event in enumerate(events):
+                        if event.record == record:
+                            prev_id = idx - 1
+                            if prev_id >= 0:
+                                self.current_record = events[prev_id].record
+                            break
         else:
             self.current_record = self.group[-1] if len(self.group) else None
         self.set_cursor(reset_view=False)
@@ -1031,8 +1045,6 @@ class Screen(SignalEvent):
     def get_buttons(self):
         'Return active buttons for the current view'
         def is_active(record, button):
-            if record.group.readonly or record.readonly:
-                return False
             if button.attrs.get('type', 'class') == 'instance':
                 return False
             states = record.expr_eval(button.attrs.get('states', {}))
@@ -1149,6 +1161,9 @@ class Screen(SignalEvent):
         if self.context:
             query_string.append(('context', json.dumps(
                         self.context, cls=JSONEncoder, separators=(',', ':'))))
+        if self.context_screen:
+            query_string.append(
+                ('context_model', self.context_screen.model_name))
         if name:
             query_string.append(
                 ('name', json.dumps(name, separators=(',', ':'))))
